==> gitaly_0.120.1%2Bdebian.orig.tar.xz: gitaly-v0.120.1/internal/service/wiki/update_page.go <==
package wiki

import (
	"fmt"

	"gitlab.com/gitlab-org/gitaly/internal/rubyserver"

	pb "gitlab.com/gitlab-org/gitaly-proto/go"

	"google.golang.org/grpc/codes"
	"google.golang.org/grpc/status"
)

func (s *server) WikiUpdatePage(stream pb.WikiService_WikiUpdatePageServer) error {
	firstRequest, err := stream.Recv()
	if err != nil {
		return err
	}

	if err := validateWikiUpdatePageRequest(firstRequest); err != nil {
		return status.Errorf(codes.InvalidArgument, "WikiUpdatePage: %v", err)
	}

	ctx := stream.Context()

	client, err := s.WikiServiceClient(ctx)
	if err != nil {
		return err
	}

	clientCtx, err := rubyserver.SetHeaders(ctx, firstRequest.GetRepository())
	if err != nil {
		return err
	}

	rubyStream, err := client.WikiUpdatePage(clientCtx)
	if err != nil {
		return err
	}

	if err := rubyStream.Send(firstRequest); err != nil {
		return err
	}

	err = rubyserver.Proxy(func() error {
		request, err := stream.Recv()
		if err != nil {
			return err
		}
		return rubyStream.Send(request)
	})

	if err != nil {
		return err
	}

	response, err := rubyStream.CloseAndRecv()
	if err != nil {
		return err
	}

	return stream.SendAndClose(response)
}

func validateWikiUpdatePageRequest(request *pb.WikiUpdatePageRequest) error {
	if len(request.GetPagePath()) == 0 {
		return fmt.Errorf("empty Page Path")
	}

	if len(request.GetTitle()) == 0 {
		return fmt.Errorf("empty Title")
	}

	if len(request.GetFormat()) == 0 {
		return fmt.Errorf("empty Format")
	}

	return validateRequestCommitDetails(request)
}

==> gitaly_1.47.3%2Bdebian.orig.tar.xz: gitaly-v1.47.3/internal/service/wiki/update_page.go <==
package wiki

import (
	"fmt"

	"gitlab.com/gitlab-org/gitaly-proto/go/gitalypb"
	"gitlab.com/gitlab-org/gitaly/internal/rubyserver"
	"google.golang.org/grpc/codes"
	"google.golang.org/grpc/status"
)

func (s *server) WikiUpdatePage(stream gitalypb.WikiService_WikiUpdatePageServer) error {
	firstRequest, err := stream.Recv()
	if err != nil {
		return err
	}

	if err := validateWikiUpdatePageRequest(firstRequest); err != nil {
		return status.Errorf(codes.InvalidArgument, "WikiUpdatePage: %v", err)
	}

	ctx := stream.Context()

	client, err := s.WikiServiceClient(ctx)
	if err != nil {
		return err
	}

	clientCtx, err := rubyserver.SetHeaders(ctx, firstRequest.GetRepository())
	if err != nil {
		return err
	}

	rubyStream, err := client.WikiUpdatePage(clientCtx)
	if err != nil {
		return err
	}

	if err := rubyStream.Send(firstRequest); err != nil {
		return err
	}

	err = rubyserver.Proxy(func() error {
		request, err := stream.Recv()
		if err != nil {
			return err
		}
		return rubyStream.Send(request)
	})

	if err != nil {
		return err
	}

	response, err := rubyStream.CloseAndRecv()
	if err != nil {
		return err
	}

	return stream.SendAndClose(response)
}

func validateWikiUpdatePageRequest(request *gitalypb.WikiUpdatePageRequest) error {
	if len(request.GetPagePath()) == 0 {
		return fmt.Errorf("empty Page Path")
	}

	if len(request.GetTitle()) == 0 {
		return fmt.Errorf("empty Title")
	}

	if len(request.GetFormat()) == 0 {
		return fmt.Errorf("empty Format")
	}

	return validateRequestCommitDetails(request)
}
